Struct ZwpVirtualKeyboardV1
pub struct ZwpVirtualKeyboardV1 { /* private fields */ }wayland and Linux only.Expand description
virtual keyboard
The virtual keyboard provides an application with requests which emulate the behaviour of a physical keyboard.
This interface can be used by clients on its own to provide raw input events, or it can accompany the input method protocol.
This interface has no events.
Implementations
impl ZwpVirtualKeyboardV1
impl ZwpVirtualKeyboardV1
pub fn keymap(&self, format: u32, fd: BorrowedFd<'_>, size: u32)
pub fn keymap(&self, format: u32, fd: BorrowedFd<'_>, size: u32)
keyboard mapping
Provide a file descriptor to the compositor which can be memory-mapped to provide a keyboard mapping description.
Format carries a value from the keymap_format enumeration.
pub fn key(&self, time: u32, key: u32, state: u32)
pub fn key(&self, time: u32, key: u32, state: u32)
key event
A key was pressed or released. The time argument is a timestamp with millisecond granularity, with an undefined base. All requests regarding a single object must share the same clock.
Keymap must be set before issuing this request.
State carries a value from the key_state enumeration.
pub fn modifiers(
&self,
mods_depressed: u32,
mods_latched: u32,
mods_locked: u32,
group: u32,
)
pub fn modifiers( &self, mods_depressed: u32, mods_latched: u32, mods_locked: u32, group: u32, )
modifier and group state
Notifies the compositor that the modifier and/or group state has changed, and it should update state.
The client should use wl_keyboard.modifiers event to synchronize its internal state with seat state.
Keymap must be set before issuing this request.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the virtual keyboard keyboard object